@@ -80,16 +80,34 @@ scale_x_grates_month <- function(
     # set environment variables to NULL so they don't mess other plots up
     grates_month_env$n <- NULL
 
-    ggplot2::scale_x_continuous(
-        trans = .grates_month_trans(
-            breaks = breaks,
-            n.breaks = n.breaks,
-            format = format,
-            bounds_format = bounds_format,
-            sep = sep,
-            n = n
+    # ggplot2 3.5.0 deprecated the `trans` argument in favour of `transform`.
+    # We could just force a minimum ggplot2 version and avoid this branching
+    # but it's relatively low effort so leaving for now.
+    # TODO - revisit.
+    if (utils::packageVersion("ggplot2") < '3.5.0') {
+        ggplot2::scale_x_continuous(
+            trans = .grates_month_trans(
+                breaks = breaks,
+                n.breaks = n.breaks,
+                format = format,
+                bounds_format = bounds_format,
+                sep = sep,
+                n = n
+            )
         )
-    )
+    } else {
+        ggplot2::scale_x_continuous(
+            transform = .grates_month_trans(
+                breaks = breaks,
+                n.breaks = n.breaks,
+                format = format,
+                bounds_format = bounds_format,
+                sep = sep,
+                n = n
+            )
+        )
+    }
+
 }
 
 # ------------------------------------------------------------------------- #
@@ -119,7 +137,7 @@ scale_type.grates_month <- function(x) {
 
     # breaks function
     brks <- function(x) {
-        if (!inherits(breaks,"waiver")) {
+        if (!inherits(breaks, "waiver")) {
             dat <- as.numeric(breaks)
         } else {
             dat <- scales::breaks_pretty(n.breaks)(as.numeric(x))
