@@ -38,13 +38,27 @@ scale_x_grates_year <- function(..., breaks = ggplot2::waiver(), n.breaks = 6L,
     .check_suggests("ggplot2")
     .check_suggests("scales") # precautionary but overkill as currently a dependency of ggplot2
 
-    ggplot2::scale_x_continuous(
-        trans = .grates_year_trans(
-            breaks = breaks,
-            n.breaks = n.breaks,
-            format = format
+    # ggplot2 3.5.0 deprecated the `trans` argument in favour of `transform`.
+    # We could just force a minimum ggplot2 version and avoid this branching
+    # but it's relatively low effort so leaving for now.
+    # TODO - revisit.
+    if (utils::packageVersion("ggplot2") < '3.5.0') {
+        ggplot2::scale_x_continuous(
+            trans = .grates_year_trans(
+                breaks = breaks,
+                n.breaks = n.breaks,
+                format = format
+            )
         )
-    )
+    } else {
+        ggplot2::scale_x_continuous(
+            transform = .grates_year_trans(
+                breaks = breaks,
+                n.breaks = n.breaks,
+                format = format
+            )
+        )
+    }
 }
 
 # -------------------------------------------------------------------------
@@ -74,7 +88,7 @@ scale_type.grates_year <- function(x) {
 
     # breaks function
     brks <- function(x) {
-        if (!inherits(breaks,"waiver")) {
+        if (!inherits(breaks, "waiver")) {
             dat <- as.numeric(breaks)
         } else {
             dat <- scales::breaks_pretty(n.breaks)(as.numeric(x))
@@ -86,7 +100,7 @@ scale_type.grates_year <- function(x) {
 
     # format function
     fmt <- function(x) {
-        x <- year(x+shift)
+        x <- year(x + shift)
         if (is.null(format)) {
             format.grates_year(x)
         } else {
